from sklearn.pipeline import Pipeline

from ows_language_model.config import config
from ows_language_model.processing import preprocessors as pp
from ows_language_model import model


pipe = Pipeline([
                ('dataset', pp.CreateDataset()),
                ('language_model', model)])
