from ows_language_model.config import config

# TODO: define model here

# defines all callbacks, scheduling and builds model here

model = None

if __name__ == '__main__':
    # could print summary
    pass
